==> jc-1.4.0.tar.gz: java/awt/List__24AccessibleAWTList__24AccessibleAWTListChild.h <==
// public class java.awt.List$AccessibleAWTList$AccessibleAWTListChild

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class b5934e7928baa904 java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild_H_
#define _JC_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild_H_

// Forward structure declarations
struct _jc_java_awt_List$object;
struct _jc_java_awt_List__24AccessibleAWTList$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleContext$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_refs	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_refs;
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_nonrefs	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_nonrefs;
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$refs	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$refs;
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$nonrefs	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$nonrefs;
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object;

typedef const struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vmethods	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vmethods;
typedef const struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtable	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtable;
typedef const struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype;

// Constructors
extern void _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$_init$5583753e2f85bbaa(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *, struct _jc_java_awt_List__24AccessibleAWTList$object *, struct _jc_java_awt_List$object *, jint);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *);
extern jint _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$getAccessibleIndexInParent$7df1a9ad90a0da6e(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *);
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *);
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method_info$getAccessibleIndexInParent$7df1a9ad90a0da6e;
extern _jc_method _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vmethods {
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *);
	jint	(*getAccessibleIndexInParent$7df1a9ad90a0da6e)(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *);
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *);
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *);
};

// Vtable
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vmethods	java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild;
};

// Vtype
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype {
	_jc_type			type;
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_refs {
	struct _jc_java_awt_List$object	*parent;
	struct _jc_java_awt_List__24AccessibleAWTList$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$refs {
    _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_refs	java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_nonrefs	java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild;
};

// Object instance structure
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object {
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype	*vtype;
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$class_object;

#endif	/* _JC_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild_H_ */

==> jc-1.4.5.tar.gz: java/awt/List__24AccessibleAWTList__24AccessibleAWTListChild.h <==
// public class java.awt.List$AccessibleAWTList$AccessibleAWTListChild

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class b5934e7928baa904 java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild_H_
#define _JC_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild_H_

// Forward structure declarations
struct _jc_java_awt_List$object;
struct _jc_java_awt_List__24AccessibleAWTList$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleContext$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_refs	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_refs;
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_nonrefs	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_nonrefs;
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$refs	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$refs;
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$nonrefs	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$nonrefs;
typedef struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object;

typedef const struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vmethods	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vmethods;
typedef const struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtable	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtable;
typedef const struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype;

// Constructors
extern void _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$_init$5583753e2f85bbaa(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *, struct _jc_java_awt_List__24AccessibleAWTList$object *, struct _jc_java_awt_List$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$getAccessibleIndexInParent$7df1a9ad90a0da6e(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method_info$getAccessibleIndexInParent$7df1a9ad90a0da6e;
extern _jc_method _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vmethods {
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *) _JC_JCNI_ATTR;
	jint	(*getAccessibleIndexInParent$7df1a9ad90a0da6e)(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vmethods	java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild;
};

// Vtype
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype {
	_jc_type			type;
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_refs {
	struct _jc_java_awt_List$object	*parent;
	struct _jc_java_awt_List__24AccessibleAWTList$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$refs {
    _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_refs	java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$sub_nonrefs	java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild;
};

// Object instance structure
struct _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$object {
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype	*vtype;
	_jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$vtype _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild$class_object;

#endif	/* _JC_java_awt_List__24AccessibleAWTList__24AccessibleAWTListChild_H_ */
